pywurfl.algorithms.wurfl.handlers.AndroidMatcher

Package pywurfl :: Package algorithms :: Package wurfl :: Module handlers :: Class AndroidMatcher |
[hide private]
[frames] | no frames]

# Class AndroidMatcher

source code

         object --+
                  |
    AbstractMatcher --+
                      |
                     AndroidMatcher

Instance Methods | [hide private]
can_handle(self, user_agent) | source code
find_matching_ua(self, user_agent) | source code
recovery_match(self, user_agent) | source code
android_os_version(self, user_agent) | source code
Inherited from `AbstractMatcher`: `__call__`, `__init__`, `add`, `catch_all_recovery_match`, `conclusive_match`, `ld_matcher`, `ris_matcher` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| androids = ``{``u'````'``:` `u'``generic_android``'``,` `u'``1_5``'``:` `u'``generic_android``...``
| android_os_re = `re.compile(r'.`*`Android`[`\s/`]``(`\d`)`\.`(`\d`)`')`
Inherited from `AbstractMatcher`: `recovery_map`, `user_agent_map`

Properties | [hide private]
Inherited from `AbstractMatcher`: `user_agents` Inherited from `object`: `__class__`

Method Details | [hide private]

### can_handle(self, user_agent) | source code
Overrides: AbstractMatcher.can_handle

### find_matching_ua(self, user_agent) | source code
Overrides: AbstractMatcher.find_matching_ua

### recovery_match(self, user_agent) | source code
Overrides: AbstractMatcher.recovery_match

Class Variable Details | [hide private]

  ### androids Value:
      {u'': u'generic_android',
       u'1_5': u'generic_android_ver1_5',
       u'1_6': u'generic_android_ver1_6',
       u'2_0': u'generic_android_ver2',
       u'2_1': u'generic_android_ver2_1',
       u'2_2': u'generic_android_ver2_2'}